@@ -74,6 +74,10 @@ public:
     virtual void swipeGestureEnd(quint32 time);
     virtual void swipeGestureCancelled(quint32 time);
 
+    virtual void holdGestureBegin(int fingerCount, quint32 time);
+    virtual void holdGestureEnd(quint32 time);
+    virtual void holdGestureCancelled(quint32 time);
+
     virtual void switchEvent(SwitchEvent *event);
 
     virtual void tabletToolEvent(TabletEvent *event);
